@@ -1,5 +1,4 @@
 import logging
-import os
 from datetime import datetime
 
 from elasticsearch import Elasticsearch
@@ -35,8 +34,7 @@ def index_error_to_es(index_obj):
         index_obj = add_timestamp_field(index_obj)
         es.index(index=in_name, id=id, body=index_obj)
     except Exception as e:
-        log_exception("index_error_to_es",
-                      "Indexing FAILED for errorID: " + index_obj["errorID"], index_obj["errorID"], e)
+        log.exception("Indexing FAILED for errorID: " + index_obj["errorID"], e)
 
 
 # Method to index audit details onto elasticsearch
@@ -47,8 +45,7 @@ def index_audit_to_es(index_obj):
         index_obj = add_timestamp_field(index_obj)
         es.index(index=es_audit_error_index, id=id, body=index_obj)
     except Exception as e:
-        log_exception("index_error_to_es",
-                      "Indexing FAILED for errorID: " + index_obj["auditID"], index_obj["auditID"], e)
+        log.exception("Indexing FAILED for errorID: " + index_obj["auditID"], e)
 
 
 # Method to generate timestamp in the format es expects per index object.
